/*
 * Copyright (c) 2022 NIBIO <http://www.nibio.no/>. 
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

package no.nibio.model.maizepheno;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;
import java.util.Collections;
import java.util.List;

/**
 * @copyright 2022 <a href="http://www.nibio.no/">NIBIO</a>
 * @author Tor-Einar Skog <tor-einar.skog@nibio.no>
 */
public class PhaseInfo{
    
    private List<Phase> phases;
    
    public PhaseInfo(List<Phase> phases){
        this.phases = phases;
        Collections.sort(this.phases);
    }
    
    
    public PhaseInfo(String phasesJson)
    {
        this.setPhases(phasesJson);
        Collections.sort(phases);
    }

    public Phase getPhase(Double heatSum) {
        for(Phase phase:this.phases)
        {
            if(heatSum < phase.getHeatReq())
            {
                return phase;
            }
        }
        // Default: Return the last phase
        return this.phases.get(this.phases.size()-1);
    }

    public void setPhases(List<Phase> phases) {
        this.phases = phases;
        Collections.sort(this.phases);
    }
    
    public final void setPhases(String phasesJson)
    {
        ObjectMapper mapper = new ObjectMapper();
        try {
            this.phases = mapper.readValue(phasesJson, new TypeReference<List<Phase>>(){});
        } catch (JsonProcessingException ex) {
            ex.printStackTrace();
        }
    }

}
